<?php
namespace Teknisa\EST\Modules\Relatorios\Controllers;

use Teknisa\EST\Controllers\TeknisaCrud;
use Teknisa\Libs\Util\NewCode;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Teknisa\EST\Modules\Relatorios\Services\Est46000EmissaoAjusteInventarioService;
use Zeedhi\Framework\Report\ReportService;

class Est46000EmissaoAjusteInventarioController extends TeknisaCrud {

	protected $novoCodigo;
 	protected $serviceMoviEst;
 	protected $reportService;

    public function __construct ($crudService, ParameterBag $parameterBag, Environment $environment, Manager $dataSourceManager, NewCode $newCode, Est46000EmissaoAjusteInventarioService $serviceMoviEst, ReportService $reportService) {
        $this->newCode = $newCode;
        $this->environment = $environment;
        $this->serviceMoviEst = $serviceMoviEst;
        parent::__construct($crudService, $parameterBag);
        $this->reportService = $reportService;
	}

	public function geraRelatorio(DTO\Request\Row $request, DTO\Response $response){
		$row = $request->getRow();

		$sequencial = $this->newCode->getCodeByTableName('MOVIESTOQUE', $row['NRORG']);

		$this->serviceMoviEst->procMovimentaEstoque($row['CDFILIAL'], ' ', ' ', ' ', 5, $row['DTPERINI'],$row['DTPERFIN'],$row['CDPRODINI'],$row['CDPRODFIN'],3,$row['CUSTOS'],$sequencial,null,null,null);

        $nvTotalizacao = $row['NPTOTALIZA']?  $row['NPTOTALIZA'] : 1;

		$relatorio = $this->serviceMoviEst->selectAjusteAnalitico($nvTotalizacao,$row['DTPERINI'],$row['DTPERFIN'],$row['CDPRODINI'],$row['CDPRODFIN'],$sequencial,$row['ORDENA'],$row['CUSTOS']);
        
        
		$totalizador = $this->serviceMoviEst->selectAjusteTotalizador($nvTotalizacao,$row['DTPERINI'],$row['DTPERFIN'],$row['CDPRODINI'],$row['CDPRODFIN'],$sequencial,$row['ORDENA'],$row['CUSTOS'],$row['CDFILIAL']);
		
        $EmissaoAjusteData = [
            'Details'=>$relatorio,
            'Totalizator'=>$totalizador
        ];
        
		$relatorio = new DataSet('EmissaoAjuste',$EmissaoAjusteData);

		$response->addDataset($relatorio);
	}
	
	public function generateBirthReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrgTrab();
        $reportStrategy = array (
            'strategy' => 'BIRT',
            'parameterMapping' => array (
                "SEQUMOVI"     => "P_SEQUMOVI",
                "CDFILIAL"     => "P_CDFILIAL",
                "DTPERINI"     => "P_DTINICIAL",
                "DTPERFIN"     => "P_DTFINAL",
                "NRORG"        => "P_NRORG"
            )
        );

        $row['SEQUMOVI'] = $this->newCode->getCodeByTableName('MOVIESTOQUE', $this->environment->getNrOrgTrab());
        $reportStrategy['parameterMapping']['CUSTOS']        = "P_CUSTO";
        $reportStrategy['parameterMapping']['CDALMOXARIFE']  = "P_CDALMOXARIFE";
        $reportStrategy['parameterMapping']['CDLOCALESTOQ']  = "P_CDLOCALESTOQ";
        $reportStrategy['parameterMapping']['NRLOTEESTOQ']   = "P_NRLOTEESTOQ";
        $reportStrategy['parameterMapping']['NPTOTALIZA']    = "P_NPTOTALIZA";
        $reportStrategy['parameterMapping']['CDPRODINI']     = "P_CDPRODINI";
        $reportStrategy['parameterMapping']['CDPRODFIN']     = "P_CDPRODFIN";
        $reportStrategy['parameterMapping']['ORDENANOME']	 = "P_ORDENANOME";
        $reportStrategy['parameterMapping']['CDFILIAL']		 = "P_CDFILIAL";
        $reportStrategy['parameterMapping']['IDLANCTO']		 = "P_IDLANCTO";
        $reportStrategy['parameterMapping']['NRORG']		 = "P_NRORG";
        $reportName = $row['REPORT_NAME'];

        
        date_default_timezone_set('America/Sao_Paulo');
        $dataEmissao = date('d/m/Y H:i');
        $reportStrategy['parameterMapping']['DTEMISSAO']      = "P_DTEMISSAO";
        $reportStrategy['parameterMapping']['PRODINI']        = "P_PRODINI";
        $reportStrategy['parameterMapping']['PRODFIN']        = "P_PRODFIN";
        $row['P_DTEMISSAO'] = $dataEmissao;
        
        $parametersRow = array();

        foreach ($reportStrategy['parameterMapping'] as $fieldName => $paramName) {
            
            if ($row->has($fieldName)) $parametersRow[$paramName] = $row->get($fieldName);
        }
     
        $parametersRow['P_CDPRODINI'] = $row['CDARVPRODINI'];
        $parametersRow['P_CDPRODFIN'] = $row['CDARVPRODFIN'];
        $parametersRow['__format'] = $row['__format'];
        $parametersRow['P_NRORG'] = $nrorg;
        $parametersRow['P_IDLANCTO'] = 3;
        $birtURL = $this->reportService->createRemoteReport('BIRT', $reportName, $parametersRow);

        $response->addDataset(new DataSet('URL',array($birtURL)));
    }

}