<?php
/**
 * Created by PhpStorm.
 * User: matheussilva
 * Date: 15/07/14
 * Time: 17:01
 */

namespace Importacao\Logic\Integracao\Mastermaq;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraMovimentoFinanceiro;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraVinculo;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraAlteracaoSalarial;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraDependente;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraFerias;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraOcupacao;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraTransferencia;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraAlteracaoSituacaoFuncional;

use \Importacao\Logic\Integracao\Mastermaq\Classes\GeraAlteracaoOcupacao;


class IntegraPersonalizado {

    private $destino;
    private $origem;

    private $tab_PAY2;
    private $tab_FERI3;
    private $tab_RESC3;
    private $tab_FUNCS;
    private $tab_BANCO;
    private $tab_SALAR;
    private $tab_FILHO;
    private $tab_FERI1;
    private $tab_FCOES;
    private $tab_TRANS;
    private $tab_AFAST;

    /**
     * @param $destino     --Endereço onde será colocado o XLS
     * @param $origem      --Endereço onde se econtra os DBF's
     * @param $tab_AFAST   --Nome dos DBF de afastamento
     * @param $tab_BANCO   --Nome dos DBF de banco
     * @param $tab_FCOES   --Nome dos DBF de funções
     * @param $tab_FERI1   --Nome dos DBF de ferias 01
     * @param $tab_FERI3   --Nome dos DBF de ferias 03
     * @param $tab_FILHO   --Nome dos DBF de filho
     * @param $tab_FUNCS   --Nome dos DBF de funcionarios
     * @param $tab_PAY2    --Nome dos DBF de pagamento
     * @param $tab_RESC3   --Nome dos DBF de recisão
     * @param $tab_SALAR   --Nome dos DBF de salário
     * @param $tab_TRANS   --Nome dos DBF de transferecia
     */
    function __construct($destino, $origem = null, $arquivos)
    {
        $this->destino = $destino;
        $this->origem = $origem;
        $this->tab_AFAST = $arquivos['AFAST'];
        $this->tab_BANCO = $arquivos['BANCO'];
        $this->tab_FCOES = $arquivos['FCOES'];
        $this->tab_FERI1 = $arquivos['FERI1'];
        $this->tab_FERI3 = $arquivos['FERI3'];
        $this->tab_FILHO = $arquivos['FILHO'];
        $this->tab_FUNCS = $arquivos['FUNCS'];
        $this->tab_PAY2 = $arquivos['PAY2_'];
        $this->tab_RESC3 = $arquivos['RESC3'];
        $this->tab_SALAR = $arquivos['SALAR'];
        $this->tab_TRANS = $arquivos['TRANS'];
    }

    public function gerar(){

        if(!empty($this->tab_PAY2) && !empty($this->tab_FERI3) && !empty($this->tab_RESC3)){
            $this->geraMovimentoFinanceiro();
        }

        if(!empty($this->tab_FUNCS) && !empty($this->tab_BANCO)){
            $this->geraVinculo();
        }

        if(!empty($this->tab_SALAR)){
            $this->geraAlteracaoSalarial();
        }

        if(!empty($this->tab_FILHO)){
            $this->geraDependente();
        }

        if(!empty($this->tab_FERI1)){
            $this->geraFerias();
        }

        if(!empty($this->tab_TRANS)){
            $this->geraTransferencia();
        }

        if(!empty($this->tab_FUNCS)){
            $this->geraOcupacao();
        }

        if(!empty($this->tab_AFAST)){
            $this->geraAlteracaoSituacaoFuncional();
        }

        if(!empty($this->tab_TRANS)){
            $this->geraAlteracaoOcupacao();
        }

    }


    private function geraMovimentoFinanceiro()
    {
        $movimentoFinanceiro = new GeraMovimentoFinanceiro($this->tab_PAY2);
        $movimentoFinanceiro->getInfo();

        $movimentoFinanceiro->connect($this->tab_FERI3);
        $movimentoFinanceiro->getInfo();

        $movimentoFinanceiro->connect($this->tab_RESC3);
        $movimentoFinanceiro->getInfo();

        $movimentoFinanceiro->gerarXls($this->destino);

    }

    private function geraVinculo()
    {
        $vinculo = new GeraVinculo($this->tab_FUNCS, $this->tab_BANCO);
        $vinculo->getInfo();
        $vinculo->gerarXls($this->destino);
    }

    private function geraAlteracaoSalarial()
    {
        $altsal = new GeraAlteracaoSalarial($this->tab_SALAR);
        $altsal->getInfo();
        $altsal->gerarXls($this->destino);
    }

    private function geraDependente()
    {
        $dependente = new GeraDependente($this->tab_FILHO);
        $dependente->getInfo();
        $dependente->gerarXls($this->destino);
    }

    private function geraFerias()
    {
        $ferias = new GeraFerias($this->tab_FERI1);
        $ferias->getInfo();
        $ferias->gerarXls($this->destino);
    }

    private function geraOcupacao()
    {
        $ocupacao = new GeraOcupacao($this->tab_FCOES);
        $ocupacao->getInfo();
        $ocupacao->gerarXls($this->destino);
    }

    private function geraTransferencia()
    {
//        $transferencia = new GeraTransferencia($this->tab_TRANS);
//        $transferencia->getInfo();
//        $transferencia->gerarXls($this->destino);
    }

    private function geraAlteracaoSituacaoFuncional()
    {
        $ocupacao = new GeraAlteracaoSituacaoFuncional($this->tab_AFAST);
        $ocupacao->getInfo();
        $ocupacao->gerarXls($this->destino);
    }

    private function geraAlteracaoOcupacao()
    {
        $ocupacao = new GeraAlteracaoOcupacao($this->tab_TRANS);
        $ocupacao->getInfo();
        $ocupacao->gerarXls($this->destino);
    }

} 